ViralQC Documentation
======================

**ViralQC** is a Python tool and package developed for virus identification and quality control from FASTA files.

.. note::
   Esta documentação também está disponível em **Português**: https://viralqc.readthedocs.io/pt/latest/

.. toctree::
   :maxdepth: 2
   :caption: Contents

   index
   installation
   configuration
   scoring
   commands
   adding-datasets
   output
   examples
   troubleshooting


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
